aboutsummaryrefslogtreecommitdiffstats
path: root/build-aux/qmi-codegen/utils.py
diff options
context:
space:
mode:
Diffstat (limited to 'build-aux/qmi-codegen/utils.py')
-rw-r--r--build-aux/qmi-codegen/utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/build-aux/qmi-codegen/utils.py b/build-aux/qmi-codegen/utils.py
index 96c3ee7..5f37d31 100644
--- a/build-aux/qmi-codegen/utils.py
+++ b/build-aux/qmi-codegen/utils.py
@@ -74,8 +74,8 @@ def add_header_start(f, output_name, service):
if service != 'CTL':
template += (
"#include \"qmi-enums-${service}.h\"\n")
- # CTL and WDS don't have flags64
- if service != 'CTL' and service != 'WDS':
+ # CTL, WDS and WMS don't have flags64
+ if service != 'CTL' and service != 'WDS' and service != 'WMS':
template += (
"#include \"qmi-flags64-${service}.h\"\n")
template += (